searchData={"items":[{"type":"module","title":"SeedHelper","doc":"","ref":"SeedHelper.html"},{"type":"function","title":"SeedHelper.begin_session/0","doc":"Begin a seeding session. This should be called in your priv/migrations/seed.exs file.","ref":"SeedHelper.html#begin_session/0"},{"type":"function","title":"SeedHelper.end_session/0","doc":"End a seeding session. This should be called in your priv/migrations/seed.exs file.","ref":"SeedHelper.html#end_session/0"},{"type":"function","title":"SeedHelper.handle/2","doc":"Get a handle to a value for use in seeds (like default_organization_id)","ref":"SeedHelper.html#handle/2"},{"type":"macro","title":"SeedHelper.if_env/2","doc":"Macro to conditionally execute a block of code based on the current build environment","ref":"SeedHelper.html#if_env/2"},{"type":"macro","title":"SeedHelper.requires_seed/2","doc":"Queue block until all required seeds have been applied.","ref":"SeedHelper.html#requires_seed/2"},{"type":"macro","title":"SeedHelper.seed/3","doc":"Execute block if seed has not been applied yet (and build env in `options[:only]` if set)","ref":"SeedHelper.html#seed/3"},{"type":"function","title":"SeedHelper.set_handle/2","doc":"Set a handle to a value for reference by other seeds.","ref":"SeedHelper.html#set_handle/2"},{"type":"module","title":"SeedHelper.Handles","doc":"","ref":"SeedHelper.Handles.html"},{"type":"function","title":"SeedHelper.Handles.handle/2","doc":"Get cached handle by name.\n\niex> get_handle(\"default_user_code\", 555)\niex> get_handle(\"default_user_code\")\n555\n\niex> get_handle(\"default_user_code_not_set\", :not_set)\n:not_set","ref":"SeedHelper.Handles.html#handle/2"},{"type":"function","title":"SeedHelper.Handles.init/0","doc":"","ref":"SeedHelper.Handles.html#init/0"},{"type":"function","title":"SeedHelper.Handles.set_handle/2","doc":"Set handle to value (which will be erlang term encoded) for reference by other seeds.\niex> set_handle(\"default_user\", 1234)\n:ok","ref":"SeedHelper.Handles.html#set_handle/2"},{"type":"module","title":"SeedHelper.Migrate","doc":"","ref":"SeedHelper.Migrate.html"},{"type":"function","title":"SeedHelper.Migrate.down/1","doc":"","ref":"SeedHelper.Migrate.html#down/1"},{"type":"function","title":"SeedHelper.Migrate.up/1","doc":"","ref":"SeedHelper.Migrate.html#up/1"},{"type":"module","title":"SeedHelper.Schema.Handles","doc":"","ref":"SeedHelper.Schema.Handles.html"},{"type":"module","title":"SeedHelper.Schema.Seeds","doc":"","ref":"SeedHelper.Schema.Seeds.html"},{"type":"module","title":"SeedHelper.Seeds","doc":"","ref":"SeedHelper.Seeds.html"},{"type":"function","title":"SeedHelper.Seeds.executed?/1","doc":"Check if {seed, version} has been executed","ref":"SeedHelper.Seeds.html#executed?/1"},{"type":"function","title":"SeedHelper.Seeds.mark_executed/1","doc":"Mark {seed, version} as executed","ref":"SeedHelper.Seeds.html#mark_executed/1"},{"type":"module","title":"SeedHelper.Session","doc":"","ref":"SeedHelper.Session.html"},{"type":"function","title":"SeedHelper.Session.await_seed/2","doc":"","ref":"SeedHelper.Session.html#await_seed/2"},{"type":"function","title":"SeedHelper.Session.begin_session/0","doc":"Initialize Seeding Session (call in your priv/migrations/seed.exs file.","ref":"SeedHelper.Session.html#begin_session/0"},{"type":"function","title":"SeedHelper.Session.end_session/0","doc":"Close session and return list of any unapplied/blocked changes.","ref":"SeedHelper.Session.html#end_session/0"},{"type":"function","title":"SeedHelper.Session.mark_applied/2","doc":"","ref":"SeedHelper.Session.html#mark_applied/2"},{"type":"extras","title":"SeedHelper","doc":"SeedHelper\n===========\n\nSeedHelper provides some simple schem and utilities for supporting incremental seeding of data in Ecto with out requiring a full \nteardown/setup to obtain consistent data sets.\n\n# Features","ref":"readme.html"},{"type":"extras","title":"Track versioned seed sections - SeedHelper","doc":"Run a seed only if it has not already been applied to current database.\n\n```elixir\nrequire SeedHelper\nimport SeedHelper\n\nseed({\"MySeed\", \"1\"}) do\n  IO.puts \"Seeding database...\"\n  # Write data here.\nend\n```","ref":"readme.html#track-versioned-seed-sections"},{"type":"extras","title":"Specify seed dependencies. - SeedHelper","doc":"Wait until required Seed.Version has been applied before executing block.\n\n```elixir\nrequire SeedHelper\nimport SeedHelper\n\nrequires_seed({\"MySeed\", \"2\"}) do\n  seed({\"MySeed\", \"1\"}) do\n    IO.puts \"Seeding database... 1\"\n  end\nend\n\n# Seed 1 will be queued into an agent until {\"MySeed\"\",2} has executed. \nseed({\"MySeed\", \"2\"}) do\n  IO.puts \"Seeding database... 2\"\nend\n```","ref":"readme.html#specify-seed-dependencies"},{"type":"extras","title":"Specify environment dependencies. - SeedHelper","doc":"Only apply seeds in test environments, prod, dev, etc. \n\n```elixir\nrequire SeedHelper\nimport SeedHelper\n\nif_env([:prod,:stage]) do\n  IO.puts \"Running in production or staging environment\"\n   seed({\"MySeed\", \"1\"}) do\n    IO.puts \"Seeding database... 1\"\n  end \nend\n\nif_env(:test) do \n  IO.puts \"Running in test environment\"\n  requires_seed({\"MySeed\", \"Core\"}) do\n    seed({\"MySeed\", \"test-data\"}) do\n      IO.puts \"Seeding database... test-data\"\n    end\n  end\nend\n\nseed({\"MySeed\", \"stuff\"}) do\n  IO.puts \"Seeding database... stuff\"\n  if_env(:test) do\n    IO.puts \"Test Specific Stuff\"\n  end\nend\n\n```","ref":"readme.html#specify-environment-dependencies"},{"type":"extras","title":"Set and Lookup handles - SeedHelper","doc":"This is useful when inserted data used generated ids but needs to be referenced by other seeds.\nhandles are stored to the SeedHelper.Schema.Handles (seed_helpers_handles) table\nbut loaded/fetched during session from an etc cache to avoid perf issues with large data sets/frequent look ups.\n\n```elixir\nrequire SeedHelper\nimport SeedHelper\n\nseed({\"MySeed\", \"core\"}) do\n    IO.puts \"Seeding database... core\"\n    # Save some record with dynamic id.\n    set_handle(\"record.id\", record.id)\nend\n\n# .\n# .\n# .\n\nseed({\"MySeed\", \"links\"}) do\n    record_id = get_handle(\"record.id\", :or_apple_if_nil)\n    # Save record referencing record_id    \nend\n\n```\n\n# Setup \n\n1. Add SeedHelper to your mix.exs file.\n    \n    ```elixir\n    defp deps do\n      [\n        {:seed_helper, \"~> 0.1.0\"}\n      ]\n    end\n    ```\n2. Set config.exs set repo for seed helper. \n\n    ```elixir\n    config :seed_helper, repo: MyApp.Repo\n    ```\n3. Setup migration\n \n    Run:\n    ``` \n    mix ecto.gen.migration setup_seed_helper \n    ```\n    \n    # Edit migration file:\n    ```\n    defmodule MyApp.Repo.Migrations.SetupSeedHelper do\n      use Ecto.Migration\n\n      def up() do \n        SeedHelper.Migration.up(1)\n      end\n   \n      def down() do \n        SeedHelper.Migration.down(1)\n      end\n    end\n    ```\n\n4. Start SeedHelper session in your priv/repo/seeds.exs file\n   ```\n   require SeedHelper\n   import SeedHelper\n   \n   # Begin SeedSession (Agent for requires_seed blocks and etc table for handle cache\n   begin_session()\n   \n   dir = Path.dirname(__ENV__.file)\n   Code.eval_file(\"#{dir}/seeds/#{Mix.env}-seeds.exs\")\n   \n   # Will throw if and requires_seeds blocks were not resolved during execution. \n   :ok = end_session() \n   ```","ref":"readme.html#set-and-lookup-handles"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Noizu Labs, inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}